import type { CompositeLayerProps } from '@deck.gl/core';
import { CompositeLayer } from '@deck.gl/core';
import { Graph } from "../graph/graph.js";
import { GraphLayout } from "../core/graph-layout.js";
import { GraphEngine } from "../core/graph-engine.js";
import { InteractionManager } from "../core/interaction-manager.js";
import { CircleLayer } from "./node-layers/circle-layer.js";
import { ImageLayer } from "./node-layers/image-layer.js";
import { LabelLayer } from "./node-layers/label-layer.js";
import { RectangleLayer } from "./node-layers/rectangle-layer.js";
import { ZoomableMarkerLayer } from "./node-layers/zoomable-marker-layer.js";
import { EdgeLayer } from "./edge-layer.js";
import { EdgeLabelLayer } from "./edge-layers/edge-label-layer.js";
import { FlowLayer } from "./edge-layers/flow-layer.js";
export type GraphLayerProps = CompositeLayerProps & _GraphLayerProps;
export type _GraphLayerProps = {
    graph?: Graph;
    layout?: GraphLayout;
    graphLoader?: (opts: {
        json: any;
    }) => Graph;
    engine?: GraphEngine;
    nodeStyle?: any[];
    edgeStyle?: {
        stroke?: string;
        strokeWidth?: number;
        /** an array of styles for layers */
        decorators?: any[];
    };
    nodeEvents?: {
        onMouseLeave?: () => void;
        onHover?: () => void;
        onMouseEnter?: () => void;
        onClick?: () => void;
        onDrag?: () => void;
    };
    edgeEvents?: {
        onClick: () => void;
        onHover: () => void;
    };
    enableDragging?: boolean;
};
export declare class GraphLayer extends CompositeLayer<GraphLayerProps> {
    static layerName: string;
    static defaultProps: Required<_GraphLayerProps>;
    state: CompositeLayer<GraphLayerProps>['state'] & {
        interactionManager: InteractionManager;
        graphEngine?: GraphEngine;
    };
    forceUpdate: () => void;
    constructor(props: GraphLayerProps & CompositeLayerProps);
    initializeState(): void;
    shouldUpdateState({ changeFlags }: {
        changeFlags: any;
    }): any;
    updateState({ props, oldProps, changeFlags }: {
        props: any;
        oldProps: any;
        changeFlags: any;
    }): void;
    finalize(): void;
    _setGraphEngine(graphEngine: GraphEngine): void;
    _removeGraphEngine(): void;
    createNodeLayers(): (CircleLayer | ImageLayer | LabelLayer | RectangleLayer | ZoomableMarkerLayer)[];
    createEdgeLayers(): (EdgeLayer | (EdgeLabelLayer | FlowLayer)[])[];
    onClick(info: any, event: any): boolean;
    onHover(info: any, event: any): boolean;
    onDragStart(info: any, event: any): void;
    onDrag(info: any, event: any): void;
    onDragEnd(info: any, event: any): void;
    renderLayers(): ((EdgeLayer | (EdgeLabelLayer | FlowLayer)[])[] | (CircleLayer | ImageLayer | LabelLayer | RectangleLayer | ZoomableMarkerLayer)[])[];
}
//# sourceMappingURL=graph-layer.d.ts.map