import { GraphLayout, GraphLayoutOptions } from "../core/graph-layout.js";
import { Node } from "../graph/node.js";
import { Graph } from "../graph/graph.js";
export type SimpleLayoutOptions = GraphLayoutOptions & {
    /** The accessor lets the application supply the position ([x, y]) of each node.
     * @example
      ```js
      <GraphGL
        {...otherProps}
        layout={
          new SimpleLayout({
            nodePositionAccessor: node => [
              node.getPropertyValue('x'),
              node.getPropertyValue('y'),
            ]
          })
        }
      />
      ```
    */
    nodePositionAccessor?: (node: Node) => [number, number];
};
/** A basic layout where the application controls positions of each node */
export declare class SimpleLayout extends GraphLayout<SimpleLayoutOptions> {
    static defaultOptions: Required<SimpleLayoutOptions>;
    protected readonly _name = "SimpleLayout";
    protected _graph: Graph | null;
    protected _nodeMap: Record<string, Node>;
    protected _nodePositionMap: Record<string, (node: Node) => [number, number]>;
    constructor(options?: SimpleLayoutOptions);
    initializeGraph(graph: Graph): void;
    _notifyLayoutComplete(): void;
    start(): void;
    update(): void;
    resume(): void;
    updateGraph(graph: Graph): void;
    setNodePositionAccessor: (accessor: any) => void;
    getNodePosition: (node: any) => any;
    getEdgePosition: (edge: any) => any;
    lockNodePosition: (node: any, x: any, y: any) => void;
}
//# sourceMappingURL=simple-layout.d.ts.map