// deck.gl-community
// SPDX-License-Identifier: MIT
// Copyright (c) vis.gl contributors
import { Edge } from "../graph/edge.js";
import { Node } from "../graph/node.js";
import { Graph } from "../graph/graph.js";
import { log } from "../utils/log.js";
const defaultParseGraphOptions = {
    nodeIdField: 'id',
    edgeSourceField: 'sourceId',
    edgeTargetField: 'targetId',
    edgeDirectedField: undefined,
    edgeDirected: false
    // nodeParser: (nodeRow: any, options: ParseGraphOptions) => ({id: nodeRow.name, data: nodeRow}),
    // edgeParser: (edgeRow: any, nodeIndexMap, options: ParseGraphOptions)=> {
    //   const sourceNodeId = edge[options.edgeSourceField];
    //   const targetNodeId = edge[options.edgeTargetField];
    //   return {
    //     id: `${sourceNodeId}-${targetNodeId}`,
    //     sourceId: nodeIndexMap[sourceNodeId],
    //     targetId: nodeIndexMap[targetNodeId],
    //     directed: true
    //   };
    // };
};
export function tableGraphLoader(tables, options) {
    options = { ...defaultParseGraphOptions, ...options };
    const { nodes, edges } = tables;
    // const nodeIndexMap = nodes.reduce((res, node, idx) => {
    //   res[idx] = node[options.nodeIdField];
    //   return res;
    // }, {});
    function defaultNodeParser(nodeRow) {
        return { id: nodeRow[options.nodeIdField] };
    }
    function defaultEdgeParser(edgeRow) {
        const sourceNodeId = edgeRow[options.edgeSourceField];
        const targetNodeId = edgeRow[options.edgeTargetField];
        return {
            id: edgeRow.id || `${sourceNodeId}-${targetNodeId}`,
            sourceId: sourceNodeId,
            targetId: targetNodeId,
            directed: options.edgeDirected
        };
    }
    const nodeParser = options.nodeParser || defaultNodeParser;
    const edgeParser = options.edgeParser || defaultEdgeParser;
    // add nodes
    if (!nodes) {
        log.error('Invalid graph: nodes is missing.')();
        return null;
    }
    const glNodes = nodes.map((node) => {
        const { id } = nodeParser(node);
        return new Node({ id, data: node });
    });
    const glEdges = edges.map((edge) => {
        const { id, sourceId, targetId, directed } = edgeParser(edge);
        return new Edge({
            id,
            sourceId,
            targetId,
            directed: directed || false,
            data: edge
        });
    });
    // create a new empty graph
    const name = 'loaded';
    const graph = new Graph({ name, nodes: glNodes, edges: glEdges });
    return graph;
}
// export function basicNodeParser(node: any): Pick<NodeOptions, 'id'> {
//   if (node.id === undefined) {
//     log.error('Invalid node: id is missing.')();
//     return null;
//   }
//   return {id: node.id};
// }
// export function basicEdgeParser(edge: any): Omit<EdgeOptions, 'data'> {
//   const {id, directed, sourceId, targetId} = edge;
//   if (sourceId === undefined || targetId === undefined) {
//     log.error('Invalid edge: sourceId or targetId is missing.')();
//     return null;
//   }
//   return {
//     id,
//     directed: directed || false,
//     sourceId,
//     targetId
//   };
// }
